@@ -84,6 +84,7 @@ def get_username_password(ctx):
 @click.argument('person')
 @click.option('-i', '--info',
               is_flag=True,
+              default=True,
               help='all information about the person',
               )
 @click.pass_context
@@ -93,8 +94,7 @@ def person(ctx, person, info):
     e = login(ctx.obj['username'], ctx.obj['password'])
     person = e.get_person(person)
 
-    if info:
-        print(json.dumps(person.data, indent=4, sort_keys=True))
+    print(json.dumps(person.data, indent=4, sort_keys=True))
 
 
 @click.command()
@@ -131,23 +131,21 @@ def user(ctx, user, delete, info, grant_service=None, revoke_service=None, set_p
     e = login(ctx.obj['username'], ctx.obj['password'])
     user = e.get_user(user)
 
-    if info:
-        print(json.dumps(user.data, indent=4, sort_keys=True))
 
     if delete:
         click.confirm(
             'Do you really want to delete this user?', abort=True)
         user.delete()
 
-    if grant_service:
+    elif grant_service:
         for service_name in grant_service:
             user.grant_service(service_name)
 
-    if revoke_service:
+    elif revoke_service:
         for service_name in revoke_service:
             user.revoke_service(service_name)
 
-    if service_password or set_password:
+    elif service_password or set_password:
         if not service_password:
             service_password = click.prompt(
                 text='Service Password', hide_input=True
@@ -172,6 +170,8 @@ def user(ctx, user, delete, info, grant_service=None, revoke_service=None, set_p
                         service['name']))
                 except ValueError as err:
                     print(err)
+    else:
+        print(json.dumps(user.data, indent=4, sort_keys=True))
 
 
 @ click.command()
@@ -186,6 +186,7 @@ def user(ctx, user, delete, info, grant_service=None, revoke_service=None, set_p
                )
 @ click.option('-i', '--info',
                is_flag=True,
+               default=True,
                help='all information about the group',
                )
 @ click.option('-a', '--add',
@@ -217,14 +218,16 @@ def group(ctx, group, delete, members, info, add=None, remove=None):
 
     if add or remove or members:
         print(json.dumps(group.members))
-
-    if info:
-        print(json.dumps(group.data, indent=4, sort_keys=True))
+        return
 
     if delete:
         click.confirm(
             'Do you really want to delete this group?', abort=True)
         group.delete()
+        return
+
+    print(json.dumps(group.data, indent=4, sort_keys=True))
+
 
 
 # default=os.environ.get('NEO4J_HOSTNAME')
